@@ -11,6 +11,8 @@ from .dependence import partialdep
 from .expectations import condexp
 from .importance import varimp
 from .shap import ShapExplainer
+from .sliceloss import slice_loss
+from .t import SliceLoss
 from .utils import create_description, df_to_dict, input_schema_to_pandas
 
 BASE_RESULTS_PATH = os.environ.get("BASE_RESULTS_PATH", "results")
@@ -30,7 +32,7 @@ def create_shapley_schema(
     profile_columns: List[str],
     explain_input_example: List[Dict],
 ):
-    """Create shapley schema for endpoint"""
+    """Create Shapley schema for endpoint"""
 
     explainer = ShapExplainer(func=func, x=x, profile_columns=profile_columns)
     folder = mkdir(endpoint_name=endpoint_name)
@@ -39,7 +41,8 @@ def create_shapley_schema(
     logging.info("Shapley - Creating schema")
     fname = "schema.json"
     fpath = os.path.join(folder, fname)
-    example = x[profile_columns].head(1)
+
+    example = pandas.DataFrame(explain_input_example).astype(x[profile_columns].dtypes)
 
     data = create_explainer_schema(
         explainer_schema_example=example,
@@ -159,6 +162,35 @@ def create_expectations(
             logging.warning(f"Could not generate valid chart for {var}: {repr(e)}")
 
 
+def create_slice_loss(
+    func: Callable,
+    x: pandas.DataFrame,
+    y: pandas.Series,
+    endpoint_name: str,
+    profile_columns: List[str],
+    kind: str,
+) -> None:
+    """Create slice loss graphs for all variables"""
+
+    if kind == "binary":
+        loss = SliceLoss.ACCURACY.value
+    elif kind == "regression":
+        loss = SliceLoss.RMSE.value
+
+    x, y = x.reset_index(drop=True), y.reset_index(drop=True)
+    folder = mkdir(endpoint_name=endpoint_name, spec_path="anatomy/sliceloss")
+
+    for var in profile_columns:
+        logging.info(f"Explanations - Creating slice loss for {var}")
+        fname = var + ".json"
+        fpath = os.path.join(folder, fname)
+        try:
+            chart = slice_loss(func, x, y, var, loss)
+            chart.save(fpath, format="json")
+        except Exception as e:
+            logging.warning(e)
+
+
 def create_importance(
     func: Callable,
     x: pandas.DataFrame,
@@ -191,6 +223,8 @@ def create_summary(
     input_names: List[str],
     output_names: str,
     kind: str,
+    path: Optional[str] = None,
+    explain_path: Optional[str] = None,
     version: Optional[str] = None,
 ) -> None:
 
@@ -201,8 +235,13 @@ def create_summary(
         "inputs": input_names,
         "output": output_names,
     }
-    if version:
+    if version is not None:
         as_json["version"] = version
+    if path is not None:
+        as_json["path"] = path
+    if explain_path is not None:
+        as_json["explain_path"] = explain_path
+
     # Save to disk
     folder = mkdir(endpoint_name=endpoint_name)
     with open(os.path.join(folder, "summary.json"), "w") as summary:
